var wrapped = function (s, wrapper) {
    return s.startsWith(wrapper) && s.endsWith(wrapper);
};
var space = {
    name: "space",
    renderer: function (_a) {
        var raw = _a.raw;
        return raw;
    }
};
var underline = {
    name: "strong",
    renderer: function (token) {
        var _a = token, raw = _a.raw, text = _a.text;
        if (wrapped(raw, "__")) {
            return "[u]".concat(text, "[/u]");
        }
        else if (wrapped(raw, "**")) {
            return "[b]".concat(text, "[/b]");
        }
        return false;
    }
};
var spoiler = {
    name: "spoiler",
    level: "inline",
    start: function (src) {
        var _a;
        // TODO Remove this hack once @types package is updated
        return (_a = src.match(/!!!/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer: function (src) {
        var match = src.match(/^!!!([^\n]*)!!!/);
        if (match) {
            return {
                type: "spoiler",
                raw: match[0],
                text: match[1],
                tokens: this.lexer.inlineTokens(match[1])
            };
        }
    },
    renderer: function (token) {
        var tokens = token.tokens;
        return "[spoiler]".concat(this.parser.parseInline(tokens), "[/spoiler]");
    }
};
var noparse = {
    name: "noparse",
    level: "block",
    start: function (src) {
        var _a;
        return (_a = src.match(/\{\{\{\n/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer: function (src) {
        var match = src.match(/^\{\{\{\n((?:.|\n)*\n)\}\}\}\n?/);
        if (match) {
            return {
                type: "noparse",
                raw: match[0],
                text: match[1]
            };
        }
    },
    renderer: function (token) {
        var text = token.text;
        return "[noparse]\n".concat(text, "[/noparse]\n\n");
    }
};
var noparsespan = {
    name: "noparsespan",
    level: "inline",
    start: function (src) {
        var _a;
        // TODO And this too
        return (_a = src.match(/\{\{\{[^\n]/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer: function (src) {
        var match = src.match(/^\{\{\{(.*)\}\}\}/);
        if (match) {
            return {
                type: "noparsespan",
                raw: match[0],
                text: match[1]
            };
        }
    },
    renderer: function (token) {
        var text = token.text;
        return "[noparse]".concat(text, "[/noparse]");
    }
};
var hr = {
    name: "hr",
    renderer: function () {
        return "[hr][/hr]\n\n";
    }
};
var blockquote = {
    name: "blockquote",
    level: "block",
    start: function (src) {
        var _a;
        return (_a = src.match(/(?:^|\n)> ?.*(?:\n|$)/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer: function (src) {
        var match = src.match(/^((?:> ?.*(?:\n|$))+)(?:\((.*)\)(?:\n|$))?/);
        if (match) {
            var _a = match, raw = _a[0], text = _a[1], author = _a[2];
            var tokens = this.lexer.blockTokens(text.replace(/^> ?/gm, ""), undefined);
            return {
                type: "blockquote",
                raw: raw,
                author: author,
                tokens: tokens
            };
        }
    },
    renderer: function (token) {
        var _a = token, tokens = _a.tokens, author = _a.author;
        var parsed = this.parser.parse(tokens);
        return "[quote".concat(author ? "=".concat(author) : "", "]").concat(parsed, "[/quote]\n\n");
    }
};
var extensions = [
    space,
    underline,
    spoiler,
    noparse,
    noparsespan,
    hr,
    blockquote,
];
export default extensions;
