// HACK: Even with the `sanitize: false`, `mangle: false`, and `sanitizer: (html) => ''` options,
//       marked still escapes some characters. This is a workaround for that.
var unescapes = {
    "&amp;": "&",
    "&lt;": "<",
    "&gt;": ">",
    "&quot;": '"',
    "&#39;": "'"
};
var unescape = function (text) {
    var regexp = new RegExp(Object.keys(unescapes).join("|"), "g");
    return text.replace(regexp, function (match) { return unescapes[match]; });
};
var renderer = {
    paragraph: function (text) {
        return text;
    },
    br: function () {
        return "\n";
    },
    heading: function (text, level) {
        return "[h".concat(level, "]").concat(text, "[/h").concat(level, "]\n\n");
    },
    em: function (text) {
        return "[i]".concat(text, "[/i]");
    },
    del: function (text) {
        return "[strike]".concat(text, "[/strike]");
    },
    link: function (href, _title, text) {
        return "[url=".concat(href, "]").concat(text, "[/url]");
    },
    image: function (href, _title, text) {
        return "[url=".concat(href, "]").concat(text, "[/url]");
    },
    list: function (body, ordered) {
        var tag = ordered ? "olist" : "list";
        return "[".concat(tag, "]\n").concat(body, "[/").concat(tag, "]");
    },
    listitem: function (text) {
        return "    [*]".concat(text, "\n");
    },
    code: function (code) {
        return "[code]\n".concat(code, "\n[/code]");
    },
    codespan: function (code) {
        return "[code]".concat(code, "[/code]");
    },
    table: function (header, body) {
        return "[table]\n".concat(header).concat(body, "[/table]\n\n");
    },
    tablerow: function (content) {
        return "  [tr]\n".concat(content, "  [/tr]\n");
    },
    tablecell: function (content, flags) {
        var tag = flags.header ? "th" : "td";
        return "    [".concat(tag, "]").concat(content, "[/").concat(tag, "]\n");
    },
    text: function (text) {
        // TODO: Switch hack with something better (marked option, custom tokenizer, etc.)
        return unescape(text);
    }
};
export default renderer;
