"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const wrapped = (s, wrapper) => s.startsWith(wrapper) && s.endsWith(wrapper);
const space = {
    name: "space",
    renderer({ raw }) {
        return raw;
    },
};
const underline = {
    name: "strong",
    renderer(token) {
        const { raw, text } = token;
        if (wrapped(raw, "__")) {
            return `[u]${text}[/u]`;
        }
        else if (wrapped(raw, "**")) {
            return `[b]${text}[/b]`;
        }
        return false;
    },
};
const spoiler = {
    name: "spoiler",
    level: "inline",
    start(src) {
        var _a;
        // TODO Remove this hack once @types package is updated
        return (_a = src.match(/!!!/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer(src) {
        const match = src.match(/^!!!([^\n]*)!!!/);
        if (match) {
            return {
                type: "spoiler",
                raw: match[0],
                text: match[1],
                tokens: this.lexer.inlineTokens(match[1]),
            };
        }
    },
    renderer(token) {
        const { tokens } = token;
        return `[spoiler]${this.parser.parseInline(tokens)}[/spoiler]`;
    },
};
const noparse = {
    name: "noparse",
    level: "block",
    start(src) {
        var _a;
        return (_a = src.match(/\{\{\{\n/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer(src) {
        const match = src.match(/^\{\{\{\n((?:.|\n)*\n)\}\}\}\n?/);
        if (match) {
            return {
                type: "noparse",
                raw: match[0],
                text: match[1],
            };
        }
    },
    renderer(token) {
        const { text } = token;
        return `[noparse]\n${text}[/noparse]\n\n`;
    },
};
const noparsespan = {
    name: "noparsespan",
    level: "inline",
    start(src) {
        var _a;
        // TODO And this too
        return (_a = src.match(/\{\{\{[^\n]/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer(src) {
        const match = src.match(/^\{\{\{(.*)\}\}\}/);
        if (match) {
            return {
                type: "noparsespan",
                raw: match[0],
                text: match[1],
            };
        }
    },
    renderer(token) {
        const { text } = token;
        return `[noparse]${text}[/noparse]`;
    },
};
const hr = {
    name: "hr",
    renderer() {
        return "[hr][/hr]\n\n";
    },
};
const blockquote = {
    name: "blockquote",
    level: "block",
    start(src) {
        var _a;
        return (_a = src.match(/(?:^|\n)> ?.*(?:\n|$)/)) === null || _a === void 0 ? void 0 : _a.index;
    },
    tokenizer(src) {
        const match = src.match(/^((?:> ?.*(?:\n|$))+)(?:\((.*)\)(?:\n|$))?/);
        if (match) {
            const [raw, text, author] = match;
            const tokens = this.lexer.blockTokens(text.replace(/^> ?/gm, ""), undefined);
            return {
                type: "blockquote",
                raw,
                author,
                tokens,
            };
        }
    },
    renderer(token) {
        const { tokens, author } = token;
        const parsed = this.parser.parse(tokens);
        return `[quote${author ? `=${author}` : ""}]${parsed}[/quote]\n\n`;
    },
};
const extensions = [
    space,
    underline,
    spoiler,
    noparse,
    noparsespan,
    hr,
    blockquote,
];
exports.default = extensions;
