"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
// HACK: Even with the `sanitize: false`, `mangle: false`, and `sanitizer: (html) => ''` options,
//       marked still escapes some characters. This is a workaround for that.
const unescapes = {
    "&amp;": "&",
    "&lt;": "<",
    "&gt;": ">",
    "&quot;": '"',
    "&#39;": "'",
};
const unescape = (text) => {
    const regexp = new RegExp(Object.keys(unescapes).join("|"), "g");
    return text.replace(regexp, (match) => unescapes[match]);
};
const renderer = {
    paragraph(text) {
        return text;
    },
    br() {
        return "\n";
    },
    heading(text, level) {
        return `[h${level}]${text}[/h${level}]\n\n`;
    },
    em(text) {
        return `[i]${text}[/i]`;
    },
    del(text) {
        return `[strike]${text}[/strike]`;
    },
    link(href, _title, text) {
        return `[url=${href}]${text}[/url]`;
    },
    image(href, _title, text) {
        return `[url=${href}]${text}[/url]`;
    },
    list(body, ordered) {
        const tag = ordered ? "olist" : "list";
        return `[${tag}]\n${body}[/${tag}]`;
    },
    listitem(text) {
        return `    [*]${text}\n`;
    },
    code(code) {
        return `[code]\n${code}\n[/code]`;
    },
    codespan(code) {
        return `[code]${code}[/code]`;
    },
    table(header, body) {
        return `[table]\n${header}${body}[/table]\n\n`;
    },
    tablerow(content) {
        return `  [tr]\n${content}  [/tr]\n`;
    },
    tablecell(content, flags) {
        const tag = flags.header ? "th" : "td";
        return `    [${tag}]${content}[/${tag}]\n`;
    },
    text(text) {
        // TODO: Switch hack with something better (marked option, custom tokenizer, etc.)
        return unescape(text);
    },
};
exports.default = renderer;
